@@ -53,7 +53,7 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     def create_channel(
         cls,
         host: str = "networkconnectivity.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -96,15 +96,15 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
         self,
         *,
         host: str = "networkconnectivity.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
-        channel: aio.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
-        quota_project_id=None,
+        channel: Optional[aio.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
         api_audience: Optional[str] = None,
@@ -259,7 +259,8 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     ) -> Callable[[hub.ListHubsRequest], Awaitable[hub.ListHubsResponse]]:
         r"""Return a callable for the list hubs method over gRPC.
 
-        Lists hubs in a given project.
+        Lists the Network Connectivity Center hubs associated
+        with a given project.
 
         Returns:
             Callable[[~.ListHubsRequest],
@@ -283,7 +284,7 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     def get_hub(self) -> Callable[[hub.GetHubRequest], Awaitable[hub.Hub]]:
         r"""Return a callable for the get hub method over gRPC.
 
-        Gets details about the specified hub.
+        Gets details about a Network Connectivity Center hub.
 
         Returns:
             Callable[[~.GetHubRequest],
@@ -309,7 +310,8 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     ) -> Callable[[gcn_hub.CreateHubRequest], Awaitable[operations_pb2.Operation]]:
         r"""Return a callable for the create hub method over gRPC.
 
-        Creates a new hub in the specified project.
+        Creates a new Network Connectivity Center hub in the
+        specified project.
 
         Returns:
             Callable[[~.CreateHubRequest],
@@ -335,8 +337,8 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     ) -> Callable[[gcn_hub.UpdateHubRequest], Awaitable[operations_pb2.Operation]]:
         r"""Return a callable for the update hub method over gRPC.
 
-        Updates the description and/or labels of the
-        specified hub.
+        Updates the description and/or labels of a Network
+        Connectivity Center hub.
 
         Returns:
             Callable[[~.UpdateHubRequest],
@@ -362,7 +364,7 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     ) -> Callable[[hub.DeleteHubRequest], Awaitable[operations_pb2.Operation]]:
         r"""Return a callable for the delete hub method over gRPC.
 
-        Deletes the specified hub.
+        Deletes a Network Connectivity Center hub.
 
         Returns:
             Callable[[~.DeleteHubRequest],
@@ -388,8 +390,8 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     ) -> Callable[[hub.ListSpokesRequest], Awaitable[hub.ListSpokesResponse]]:
         r"""Return a callable for the list spokes method over gRPC.
 
-        Lists the spokes in the specified project and
-        location.
+        Lists the Network Connectivity Center spokes in a
+        specified project and location.
 
         Returns:
             Callable[[~.ListSpokesRequest],
@@ -413,7 +415,8 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     def get_spoke(self) -> Callable[[hub.GetSpokeRequest], Awaitable[hub.Spoke]]:
         r"""Return a callable for the get spoke method over gRPC.
 
-        Gets details about the specified spoke.
+        Gets details about a Network Connectivity Center
+        spoke.
 
         Returns:
             Callable[[~.GetSpokeRequest],
@@ -439,8 +442,7 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     ) -> Callable[[hub.CreateSpokeRequest], Awaitable[operations_pb2.Operation]]:
         r"""Return a callable for the create spoke method over gRPC.
 
-        Creates a spoke in the specified project and
-        location.
+        Creates a Network Connectivity Center spoke.
 
         Returns:
             Callable[[~.CreateSpokeRequest],
@@ -466,7 +468,8 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     ) -> Callable[[hub.UpdateSpokeRequest], Awaitable[operations_pb2.Operation]]:
         r"""Return a callable for the update spoke method over gRPC.
 
-        Updates the parameters of the specified spoke.
+        Updates the parameters of a Network Connectivity
+        Center spoke.
 
         Returns:
             Callable[[~.UpdateSpokeRequest],
@@ -492,7 +495,7 @@ class HubServiceGrpcAsyncIOTransport(HubServiceTransport):
     ) -> Callable[[hub.DeleteSpokeRequest], Awaitable[operations_pb2.Operation]]:
         r"""Return a callable for the delete spoke method over gRPC.
 
-        Deletes the specified spoke.
+        Deletes a Network Connectivity Center spoke.
 
         Returns:
             Callable[[~.DeleteSpokeRequest],
